Range-v3: range/v3/action/insert.hpp File Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Classes | Typedefs | Functions | Variables
insert.hpp File Reference

## Classes
struct | ranges::concepts::InsertableRange
struct | ranges::v3::insert_fn

## Typedefs
template<typename Rng , typename... Rest>
using | ranges::InsertableRange = concepts::models< concepts::InsertableRange, Rng, Rest... >

## Functions
template<typename Cont , typename P , typename I , typename S , typename C = common_iterator_t<I, S>, requires = (LvalueContainerLike<Cont>() && Iterator<P>() && Sentinel<S, I>() && !Range<S>())>
auto | ranges::v3::insert (Cont &&cont, P p, I i, S j) -> decltype(detail::insert_impl(static_cast< Cont &&>(cont), std::move(p), std::move(i), std::move(j), meta::strict_and< RandomAccessReservable< Cont >, SizedSentinel< S, I >>
template<typename Cont , typename I , typename Rng , typename C = range_common_iterator_t<Rng>, requires = (LvalueContainerLike<Cont>() && Iterator<I>() && Range<Rng>())>
auto | ranges::v3::insert (Cont &&cont, I p, Rng &&rng) -> decltype(detail::insert_impl(static_cast< Cont &&>(cont), std::move(p), static_cast< Rng &&>(rng), meta::strict_and< RandomAccessReservable< Cont >, SizedRange< Rng >>

## Variables
constexpr adl_insert_detail::insert_fn | ranges::insert {}